@@ -4,16 +4,16 @@
 modname = 'wireit'
 distname = 'cubicweb-wireit'
 
-numversion = (1, 0, 0)
+numversion = (1, 3, 0)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
 author = 'LOGILAB S.A. (Paris, FRANCE)'
 author_email = 'contact@logilab.fr'
 description = 'WireIt workflow store for the CubicWeb framework'
-web = 'http://www.cubicweb.org/project/%s' % distname
+web = 'https://forge.extranet.logilab.fr/cubicweb/cubes/%s' % distname
 
-__depends__ = {'cubicweb': '>= 3.25.0',
+__depends__ = {'cubicweb': ">= 3.38.0, < 3.39.0",
                'cubicweb-file': None}
 __recommends__ = {}
 
