@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# copyright 2012 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2012-2022 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr -- mailto:contact@logilab.fr
 #
 # This program is free software: you can redistribute it and/or modify it under
@@ -18,7 +18,7 @@
 """simple views (typically one line or so) for cubicweb-wireit"""
 
 from cubicweb.predicates import is_instance
-from cubicweb.web.views.baseviews import InContextView
+from cubicweb_web.views.baseviews import InContextView
 
 
 class UploadedFileInContextView(InContextView):
