@@ -1,4 +1,4 @@
-# copyright 2012-2013 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2012-2022 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr -- mailto:contact@logilab.fr
 #
 # This program is free software: you can redistribute it and/or modify it under
@@ -17,7 +17,7 @@
 
 from cubicweb import _
 from cubicweb.predicates import match_user_groups, is_instance
-from cubicweb.web.action import Action
+from cubicweb_web.action import Action
 
 
 class WiringAdminViewSourceJson(Action):
