@@ -1,4 +1,4 @@
-# copyright 2012-2013 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2012-2022 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr -- mailto:contact@logilab.fr
 #
 # This program is free software: you can redistribute it and/or modify it under
@@ -15,7 +15,7 @@
 # with this program. If not, see <http://www.gnu.org/licenses/>.
 
 from cubicweb.predicates import is_instance, match_form_params
-from cubicweb.web.views.primary import PrimaryView
+from cubicweb_web.views.primary import PrimaryView
 
 from cubicweb_wireit.views.mixins import WiringViewMixin
 
